# Scratchpad

> Temporary notes during task execution. **Cleared after task completion.**

## Current Task Notes

<!-- AI writes temporary observations here -->

## Pending Questions

<!-- Questions to clarify with human -->

## References Found

<!-- Useful code snippets or documentation links -->
